==> owncloud-app-documents-1%3A0.10.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/documents/l10n/mk.js <==
OC.L10N.register(
    "documents",
    {
    "Documents" : "Документи",
    "Can't create document" : "Не можам да креирам документ",
    "You don't have permission to rename this document" : "Немате дозвола да го преименувате овој документ",
    "Directory saved successfully." : "Папката успешно е снимена.",
    "An error occurred while changing directory." : "Се случи грешка при промена на папката.",
    "Saved" : "Снимено",
    "Format filter server is down or misconfigured" : "Серверот за филтери за форматирање е паднат или е погрешно конфигуриран",
    "Conversion failed. Check log for details." : "Конверзацијата не успеа. Проверете го дневникот за детали.",
    "Saving..." : "Снимам...",
    "Failed to load documents." : "Не успеав да го вчитам документот",
    "No documents were found. Upload or create a document to get started!" : "Не се најдени документи. Префрлете или креирајте документ за да почнете!",
    "No connection to server. Trying to reconnect." : "Нема врска до серверот. Пробувам да се врзам повторно.",
    "Leaving this page in Editor mode might cause unsaved data. It is recommended to use 'Close' button instead." : "Оставањето на оваа страница во мод за уредување може да предизивка губиток на неснимените податоци. Се препорачува да се користи копчето 'Затвори'.",
    "Failed to load this document. Please check if it can be opened with an external odt editor. This might also mean it has been unshared or deleted recently." : "Неуспешно вчитување на документот. Ве молиме да проверите дали може да се отвори со надворешен odt уредувач. Ова исто така може да значи дека истиот бил отстранет од споделување или пак претходно бил избришан.",
    "Save" : "Сними",
    "Loading documents..." : "Вчитувам документи...",
    "'.' is an invalid file name." : "'.' е грешно име за датотека.",
    "File name cannot be empty." : "Името на датотеката не може да биде празно.",
    "Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed." : "Неправилно име. , '\\', '/', '<', '>', ':', '\"', '|', '?' и '*' не се дозволени.",
    "Align Left" : "Подреди налево",
    "Alignment" : "Подредување",
    "Align Right" : "Подреди надесно",
    "Annotate" : "Коментар",
    "Background" : "Позадина",
    "Bold" : "Здебелено",
    "Bottom" : "Дно",
    "Cancel" : "Откажи",
    "Center" : "Центар",
    "Clone" : "Клонирај",
    "Clone this Style" : "Клонирај го овој стил",
    "Close" : "Затвори",
    "Color" : "Боја",
    "Create" : "Создај",
    "Decrease Indent" : "Намали го вовлекувањето",
    "Default Style" : "Преддефиниран стил",
    "Delete" : "Избриши",
    "Family" : "Фамилија",
    "Font" : "Фонт",
    "Font Effects" : "Фонт ефекти",
    "Format" : "Форматирање",
    "Increase Indent" : "Зголеми го вовлекувањето",
    "Insert Image" : "Вметни слика",
    "Invite Members" : "Покани членови",
    "Italic" : "Закосено",
    "Justified" : "Порамнето",
    "Justify" : "Порамни",
    "Left" : "Лево",
    "Loading" : "Вчитувам ...",
    "Members" : "Членови",
    "New Name:" : "Ново име:",
    "OK" : "Во ред",
    "Open" : "Отвори",
    "Options" : "Опции",
    "Paragraph..." : "Параграф...",
    "Paragraph Styles" : "Стилови на параграф",
    "Redo" : "Повторно изврши",
    "Right" : "Десно",
    "Size" : "Големина",
    "Spacing" : "Раздел",
    "Style" : "Стил",
    "Text" : "Текст",
    "Top" : "На врв",
    "Underline" : "Подвлечи",
    "Undo" : "Поништи",
    "Unknown Author" : "Непознат автор",
    "Edit" : "Уреди",
    "Share" : "Сподели",
    "guest" : "гостин",
    "MS Word support (requires openOffice/libreOffice)" : "Поддршка за MS Word (побарува openOffice/libreOffice)",
    "Local" : "Локален",
    "openOffice/libreOffice is installed on this server. Path to binary is provided via preview_libreoffice_path in config.php" : "openOffice/libreOffice е инсталиран на овој сервер. Патеката до бинарната датотека е  обезбедена преку preview_libreoffice_path во config.php",
    "External" : "Надворешен",
    "openOffice/libreOffice is installed on external server running a format filter server" : "openOffice/libreOffice е инсталиран на надворешен сервер кој опслужува сервер за форматирање на филтри",
    "Disabled" : "Оневозможен",
    "No MS Word support" : "Нема поддршка за ",
    "Server URL" : "URL на серверот",
    "Apply and test" : "Примени и тестирај",
    "New document" : "Нов документ",
    "Upload (max. %s)" : "Префрлање (макс. %s)",
    "Upload" : "Префрли",
    "Save new documents to" : "Сними ги новите документи во",
    "Wrong password. Please retry." : "Погрешна лозинка. Обиди се повторно.",
    "Password" : "Лозинка",
    "Guest %s" : "Гостин %s",
    "This link has been expired or is never existed. Please contact the person who shared it with you for details." : "Овој линк истекол или никогаш не постоел. Ве молиме контактирајте го корисникот кој го споделил линкот со вас за повеќе детали.",
    "Advanced feature-set" : "Напредни опции",
    "(Unstable)" : "(Нестабилен)"
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");

==> owncloud-app-documents-1%3A8.2.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/documents/l10n/mk.js <==
OC.L10N.register(
    "documents",
    {
    "Documents" : "Документи",
    "Can't create document" : "Не можам да креирам документ",
    "You don't have permission to rename this document" : "Немате дозвола да го преименувате овој документ",
    "Directory saved successfully." : "Папката успешно е снимена.",
    "An error occurred while changing directory." : "Се случи грешка при промена на папката.",
    "Saved" : "Снимено",
    "Format filter server is down or misconfigured" : "Серверот за филтери за форматирање е паднат или е погрешно конфигуриран",
    "Conversion failed. Check log for details." : "Конверзацијата не успеа. Проверете го дневникот за детали.",
    "Saving..." : "Снимам...",
    "Failed to load documents." : "Не успеав да го вчитам документот",
    "No documents were found. Upload or create a document to get started!" : "Не се најдени документи. Префрлете или креирајте документ за да почнете!",
    "No connection to server. Trying to reconnect." : "Нема врска до серверот. Пробувам да се врзам повторно.",
    "Leaving this page in Editor mode might cause unsaved data. It is recommended to use 'Close' button instead." : "Оставањето на оваа страница во мод за уредување може да предизивка губиток на неснимените податоци. Се препорачува да се користи копчето 'Затвори'.",
    "Failed to load this document. Please check if it can be opened with an external odt editor. This might also mean it has been unshared or deleted recently." : "Неуспешно вчитување на документот. Ве молиме да проверите дали може да се отвори со надворешен odt уредувач. Ова исто така може да значи дека истиот бил отстранет од споделување или пак претходно бил избришан.",
    "Save" : "Сними",
    "Loading documents..." : "Вчитувам документи...",
    "'.' is an invalid file name." : "'.' е грешно име за датотека.",
    "File name cannot be empty." : "Името на датотеката не може да биде празно.",
    "Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed." : "Неправилно име. , '\\', '/', '<', '>', ':', '\"', '|', '?' и '*' не се дозволени.",
    "Align Left" : "Подреди налево",
    "Alignment" : "Подредување",
    "Align Right" : "Подреди надесно",
    "Annotate" : "Коментар",
    "Background" : "Позадина",
    "Bold" : "Здебелено",
    "Bottom" : "Дно",
    "Cancel" : "Откажи",
    "Center" : "Центар",
    "Clone" : "Клонирај",
    "Clone this Style" : "Клонирај го овој стил",
    "Close" : "Затвори",
    "Color" : "Боја",
    "Create" : "Создај",
    "Decrease Indent" : "Намали го вовлекувањето",
    "Default Style" : "Преддефиниран стил",
    "Delete" : "Избриши",
    "Family" : "Фамилија",
    "Font" : "Фонт",
    "Font Effects" : "Фонт ефекти",
    "Format" : "Форматирање",
    "Increase Indent" : "Зголеми го вовлекувањето",
    "Insert Image" : "Вметни слика",
    "Invite Members" : "Покани членови",
    "Italic" : "Закосено",
    "Justified" : "Порамнето",
    "Justify" : "Порамни",
    "Left" : "Лево",
    "Loading" : "Вчитувам ...",
    "Members" : "Членови",
    "New Name:" : "Ново име:",
    "OK" : "Во ред",
    "Open" : "Отвори",
    "Options" : "Опции",
    "Paragraph..." : "Параграф...",
    "Paragraph Styles" : "Стилови на параграф",
    "Redo" : "Повторно изврши",
    "Right" : "Десно",
    "Size" : "Големина",
    "Spacing" : "Раздел",
    "Style" : "Стил",
    "Text" : "Текст",
    "Top" : "На врв",
    "Underline" : "Подвлечи",
    "Undo" : "Поништи",
    "Unknown Author" : "Непознат автор",
    "Shared" : "Споделен",
    "Error" : "Грешка",
    "Error while sharing" : "Грешка при споделување",
    "Error while unsharing" : "Грешка при прекин на споделување",
    "Error while changing permissions" : "Грешка при промена на привилегии",
    "Shared with you and the group {group} by {owner}" : "Споделено со Вас и групата {group} од {owner}",
    "Shared with you by {owner}" : "Споделено со Вас од {owner}",
    "Share with users or groups …" : "Сподели со корисници или групи ...",
    "Share with users, groups or remote users …" : "Споделено со корисници, групи или оддалечени корисници ...",
    "Share" : "Сподели",
    "Share link" : "Сподели ја врската",
    "Password protect" : "Заштити со лозинка",
    "Password" : "Лозинка",
    "Email link to person" : "Прати врска по е-пошта на личност",
    "Send" : "Прати",
    "Set expiration date" : "Постави рок на траење",
    "Expiration" : "Истекување",
    "Expiration date" : "Рок на траење",
    "group" : "група",
    "Resharing is not allowed" : "Повторно споделување не е дозволено",
    "Shared in {item} with {user}" : "Споделено во {item} со {user}",
    "Unshare" : "Не споделувај",
    "notify by email" : "извести преку електронска пошта",
    "can share" : "може да споделува",
    "can edit" : "може да се измени",
    "access control" : "контрола на пристап",
    "create" : "креирај",
    "delete" : "избриши",
    "Password protected" : "Заштитено со лозинка",
    "Error unsetting expiration date" : "Грешка при тргање на рокот на траење",
    "Error setting expiration date" : "Грешка при поставување на рок на траење",
    "Sending ..." : "Праќање...",
    "Email sent" : "Е-порака пратена",
    "Warning" : "Предупредување",
    "Edit" : "Уреди",
    "guest" : "гостин",
    "MS Word support (requires openOffice/libreOffice)" : "Поддршка за MS Word (побарува openOffice/libreOffice)",
    "Local" : "Локален",
    "openOffice/libreOffice is installed on this server. Path to binary is provided via preview_libreoffice_path in config.php" : "openOffice/libreOffice е инсталиран на овој сервер. Патеката до бинарната датотека е  обезбедена преку preview_libreoffice_path во config.php",
    "External" : "Надворешен",
    "openOffice/libreOffice is installed on external server running a format filter server" : "openOffice/libreOffice е инсталиран на надворешен сервер кој опслужува сервер за форматирање на филтри",
    "Disabled" : "Оневозможен",
    "No MS Word support" : "Нема поддршка за ",
    "Server URL" : "URL на серверот",
    "Apply and test" : "Примени и тестирај",
    "New document" : "Нов документ",
    "Upload (max. %s)" : "Префрлање (макс. %s)",
    "Upload" : "Префрли",
    "Save new documents to" : "Сними ги новите документи во",
    "Wrong password. Please retry." : "Погрешна лозинка. Обиди се повторно.",
    "Guest %s" : "Гостин %s",
    "This link has been expired or is never existed. Please contact the person who shared it with you for details." : "Овој линк истекол или никогаш не постоел. Ве молиме контактирајте го корисникот кој го споделил линкот со вас за повеќе детали.",
    "Advanced feature-set" : "Напредни опции",
    "(Unstable)" : "(Нестабилен)"
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
